/**
 * @license
 *-------------------------------------------------------------------------------------------
 * Copyright © 2025 Progress Software Corporation. All rights reserved.
 * Licensed under commercial license. See LICENSE.md in the package root for more information
 *-------------------------------------------------------------------------------------------
 */
import { ComponentOptionsMixin } from 'vue';
import { ComponentProvideOptions } from 'vue';
import { DefineComponent } from 'vue';
import { ExtractPropTypes } from 'vue';
import { PropType } from 'vue';
import { PublicProps } from 'vue';

/**
 * @hidden
 */
export declare const ListView: DefineComponent<ExtractPropTypes<    {
dataItems: PropType<any[]>;
item: PropType<any>;
header: PropType<any>;
footer: PropType<any>;
}>, {}, {}, {}, {
onScroll(event: any): void;
}, ComponentOptionsMixin, ComponentOptionsMixin, {
scroll: any;
}, string, PublicProps, Readonly<ExtractPropTypes<    {
dataItems: PropType<any[]>;
item: PropType<any>;
header: PropType<any>;
footer: PropType<any>;
}>> & Readonly<{
onScroll?: (...args: any[] | unknown[]) => any;
}>, {}, {}, {}, {}, string, ComponentProvideOptions, true, {}, any>;

/**
 * @hidden
 */
export declare const ListViewFooter: DefineComponent<    {}, {}, {}, {}, {}, ComponentOptionsMixin, ComponentOptionsMixin, {}, string, PublicProps, Readonly<{}> & Readonly<{}>, {}, {}, {}, {}, string, ComponentProvideOptions, true, {}, any>;

export declare interface ListViewFooterProps {
    /**
     * Add additional classes to the ListViewFooter.
     */
    class?: string;
}

/**
 * @hidden
 */
export declare const ListViewHeader: DefineComponent<    {}, {}, {}, {}, {}, ComponentOptionsMixin, ComponentOptionsMixin, {}, string, PublicProps, Readonly<{}> & Readonly<{}>, {}, {}, {}, {}, string, ComponentProvideOptions, true, {}, any>;

export declare interface ListViewHeaderProps {
    /**
     * Add additional classes to the ListViewHeader.
     */
    class?: string;
}

/**
 * Represents the props of the each ListView item.
 */
export declare interface ListViewItemProps {
    /**
     * The data object that represents the current item.
     */
    dataItem: any;
    /**
     * The index of the item in the data collection.
     */
    index?: number;
}

/**
 * Represents the props of the [Kendo UI for Vue ListView component]({% slug overview_listview %}).
 */
export declare interface ListViewProps {
    /**
     * Sets the data of the ListView.
     */
    dataItems?: any[];
    /**
     * Defines the component that will be rendered for each item of the data collection.
     */
    item?: any;
    /**
     * Defines the component that will be rendered for ListView header.
     */
    header?: any;
    /**
     * Defines the component that will be rendered for ListView footer.
     */
    footer?: any;
    /**
     * Fires when the ListView has been scrolled.
     */
    onScroll?: (event: ListViewScrollEvent) => void;
}

/**
 * Represents the object of the `Native Scroll` event ([see example](slug:listview_events)).
 */
export declare interface ListViewScrollEvent {
    /**
     * The object that holds the Native Scroll event properties.
     */
    event: any;
}

export { }
